@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: start_app.py 11481 2019-04-24 02:34:18Z Lavender $
+# $Id: start_app.py 11938 2020-02-19 07:52:03Z Lavender $
 #
 # Copyright (c) 2016 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2019-04-24 10:34:18 +0800 (週三, 24 四月 2019) $
-# $Revision: 11481 $
+# $Date: 2020-02-19 16:52:03 +0900 (週三, 19 二月 2020) $
+# $Revision: 11938 $
 
 import os
 import sys
@@ -46,7 +46,7 @@ class Command(BaseCommand):
         def findSettings(path):
             for root, dirs, files in os.walk(path):
                 for f in files:
-                    if f == 'settings.txt':
+                    if f == 'settings.py':
                         return os.path.join(root, f)
             return None
         projectName = os.path.dirname(findSettings('.'))
@@ -55,15 +55,15 @@ class Command(BaseCommand):
         call_command('startapp', name)
 
         # add header
-        context = Context({
+        context = {
             "year": datetime.date.today().year, 
-        })
+        }
         temp = get_template('scaffold/HeaderTemplate.txt')
         header = temp.render(context)
 
-        context = Context({
+        context = {
             "projectName": projectName, 
-        })
+        }
         temp = get_template('scaffold/ScrapySettings.txt')
         scrapySettings = temp.render(context)
 
@@ -77,7 +77,7 @@ class Command(BaseCommand):
                 with open(path, 'r') as f:
                     content = f.read()
                 content = header + content
-                with open(path, 'w') as f:
+                with open(path, 'wb') as f:
                     f.write(utf8(content))
 
         if options['scrapy']:
